@@ -846,11 +846,11 @@ def XGB_Eleccion(df2,df3,cve,k):
             c3=c3+1 
     p=max(c1,c2,c3)
     if p==c2:
-        print("El método de Random Forest escogido será con indexación 10. Se procederá a guardarlo")
+        print("El método de Xtreme Gradient Boosting escogido será con indexación 10. Se procederá a guardarlo")
         joblib.dump(xgb2,"XGB2_"+str(cve)+".joblib")
         return yrl10_test,y_pred66,xgb2
     elif p==c3:
-        print("El método de Random Forest escogido será con indexación 5. Se procederá a guardarlo")
+        print("El método de Xtreme Gradient Boosting será con indexación 5. Se procederá a guardarlo")
         joblib.dump(xgb3,"XGB3_"+str(cve)+".joblib")
         return yrl5_test,y_pred69,xgb3
     elif p==c1:
